compress

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 8, 2025 License: GPL-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CompressZlib

func CompressZlib(data []byte) ([]byte, error)

CompressZlib compresses data using zlib compression

func DecompressZlib

func DecompressZlib(compressed []byte) ([]byte, error)

DecompressZlib decompresses zlib-compressed data

func DecompressZlibWithSize

func DecompressZlibWithSize(compressed []byte, decompressedSize int) ([]byte, error)

DecompressZlibWithSize decompresses zlib data with a known decompressed size This is useful for encrypted files where the compressed stream may have padding

Types

This section is empty.

Jump to